You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@accumulo.apache.org by el...@apache.org on 2013/07/31 04:00:00 UTC

[40/50] [abbrv] git commit: ACCUMULO-1550 committing Jonathan Hsieh's patch

ACCUMULO-1550 committing Jonathan Hsieh's patch


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/cd8ebfe8
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/cd8ebfe8
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/cd8ebfe8

Branch: refs/heads/1.5.1-SNAPSHOT
Commit: cd8ebfe895726695378644fad55e886022d67fc6
Parents: 8113ca6
Author: Eric Newton <er...@gmail.com>
Authored: Wed Jul 17 11:56:29 2013 -0400
Committer: Eric Newton <er...@gmail.com>
Committed: Wed Jul 17 11:56:29 2013 -0400

----------------------------------------------------------------------
 README                                          | 10 ++--
 bin/accumulo                                    | 63 +++++++++++++-------
 bin/config.sh                                   | 61 +++++++++++++------
 bin/start-all.sh                                |  8 +--
 bin/start-here.sh                               |  6 +-
 bin/start-server.sh                             |  2 +-
 bin/stop-all.sh                                 |  4 +-
 bin/stop-here.sh                                |  4 +-
 bin/tdown.sh                                    |  2 +-
 bin/tup.sh                                      |  2 +-
 .../1GB/native-standalone/accumulo-env.sh       |  6 +-
 conf/examples/1GB/standalone/accumulo-env.sh    |  6 +-
 .../2GB/native-standalone/accumulo-env.sh       |  6 +-
 conf/examples/2GB/standalone/accumulo-env.sh    |  6 +-
 .../3GB/native-standalone/accumulo-env.sh       |  6 +-
 conf/examples/3GB/standalone/accumulo-env.sh    |  6 +-
 .../512MB/native-standalone/accumulo-env.sh     |  6 +-
 conf/examples/512MB/standalone/accumulo-env.sh  |  6 +-
 docs/config.html                                |  2 +-
 .../org/apache/accumulo/server/Accumulo.java    |  4 +-
 .../start/classloader/AccumuloClassLoader.java  | 11 +++-
 .../java/org/apache/accumulo/start/Test.java    |  1 +
 test/system/auto/TestUtils.py                   |  2 +-
 test/system/continuous/agitator.pl              |  2 +-
 test/system/continuous/magitator.pl             |  6 +-
 test/system/continuous/mapred-setup.sh          |  2 +-
 test/system/continuous/start-stats.sh           |  2 +-
 test/system/randomwalk/README                   |  2 +-
 test/system/randomwalk/bin/reset-cluster.sh     | 10 ++--
 test/system/randomwalk/bin/start-all.sh         |  4 +-
 test/system/randomwalk/bin/start-local.sh       |  4 +-
 test/system/scalability/run.py                  |  2 +-
 32 files changed, 158 insertions(+), 106 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/README
----------------------------------------------------------------------
diff --git a/README b/README
index 1f514de..8cfbd53 100644
--- a/README
+++ b/README
@@ -82,12 +82,12 @@ accumulo client code.  These directories must be at the same location on every
 node in the cluster.
 
 If you are configuring a larger cluster you will need to create the configuration
-files yourself and propogate the changes to the $ACCUMULO_HOME/conf directories:
+files yourself and propogate the changes to the $ACCUMULO_CONF_DIR directories:
 
-   Create a "slaves" file in $ACCUMULO_HOME/conf/.  This is a list of machines
+   Create a "slaves" file in $ACCUMULO_CONF_DIR/.  This is a list of machines
    where tablet servers and loggers will run.
 
-   Create a "masters" file in $ACCUMULO_HOME/conf/.  This is a list of
+   Create a "masters" file in $ACCUMULO_CONF_DIR/.  This is a list of
    machines where the master server will run. 
 
    Create conf/accumulo-env.sh following the template of
@@ -202,7 +202,7 @@ server, but you can also glob them if you wish.
 
   kadmin.local -q "xst -k accumulo.keytab -glob accumulo*"
 
-Place this file in $ACCUMULO_HOME/conf for every host. It should be owned by
+Place this file in $ACCUMULO_CONF_DIR for every host. It should be owned by
 the accumulo user and chmodded to 400. Add the following to the accumulo-env.sh
 
 In the accumulo-site.xml file on each node, add settings for general.kerberos.keytab
@@ -213,7 +213,7 @@ _HOST in lieu of your individual host names.
 
   <property>
     <name>general.kerberos.keytab</name>
-    <value>$ACCUMULO_HOME/conf/accumulo.keytab</value>
+    <value>$ACCUMULO_CONF_DIR/accumulo.keytab</value>
   </property>
 
   <property>

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/accumulo
----------------------------------------------------------------------
diff --git a/bin/accumulo b/bin/accumulo
index e1d269c..42074b6 100755
--- a/bin/accumulo
+++ b/bin/accumulo
@@ -15,12 +15,54 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# The main Accumulo command script.  
+#
+# Environment variables parameters: 
+#
+#  JAVA_HOME           The java implenetation to use. 
+#  ACCUMULO_CONF_DIR   Location where accumulo-env.sh, accumulo-site.xml and friends will be read from
+#  ACCUMULO_LOG_DIR    Directory for accmulo daemon logs.  defaults to $ACCUMULO_HOME/logs
+#  ACCUMULO_VERSION    This Accumulo's version number 
+#  HADOOP_HOME         The home diretcory for HADOOP.  Defaults to bin/hadoop's parent.
+# 
+# Java jvm paramters:  (-Xmx et al)
+# 
+#  ACCUMULO_TSERVER_OPTS
+#  ACCUMULO_MASTER_OPTS
+#  ACCUMULO_GC_OPTS
+#  ACCUMULO_MONITOR_OPTS
+#  ACCUMULO_LOGGER_OPTS
+#  ACCUMULO_GENERAL_OPTS
+#  ACCUMULO_OTHER_OPTS
+# 
+# Environment variables overriden by config.sh
+#
+#  ACCUMULO_HOME     Always the parent dir of bin/accumulo
 
 bin=`dirname "$0"`
 bin=`cd "$bin"; pwd`
 
 . "$bin"/config.sh
 
+if [ -z "$JAVA_HOME" -o ! -d "$JAVA_HOME" ]; then
+    echo "JAVA_HOME is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
+    exit 1
+fi
+if [ -z "$HADOOP_HOME" -o ! -d "$HADOOP_HOME" ]; then
+    echo "HADOOP_HOME is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
+    exit 1
+fi
+if [ -z "$ZOOKEEPER_HOME" -o ! -d "$ZOOKEEPER_HOME" ]; then
+    echo "ZOOKEEPER_HOME is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
+    exit 1
+fi
+
+#Export the variables just in case they are not exported
+#This makes them available to java
+export JAVA_HOME=$JAVA_HOME
+export HADOOP_HOME=$HADOOP_HOME
+export ZOOKEEPER_HOME=$ZOOKEEPER_HOME
+
 START_JAR=$ACCUMULO_HOME/lib/accumulo-start-$ACCUMULO_VERSION.jar
 COMMONS_JCI_JARS=$ACCUMULO_HOME/lib/commons-jci-core-1.0.jar:$ACCUMULO_HOME/lib/commons-jci-fam-1.0.jar:$ACCUMULO_HOME/lib/log4j-1.2.16.jar:$ACCUMULO_HOME/lib/commons-logging-1.0.4.jar:$ACCUMULO_HOME/lib/commons-logging-api-1.0.4.jar
 START_CLASSES_DIR=$ACCUMULO_HOME/src/start/target/classes
@@ -81,28 +123,9 @@ else
 	export ACCUMULO_OPTS="${ACCUMULO_GENERAL_OPTS} ${ACCUMULO_OTHER_OPTS}"
 fi
 
-XML_FILES=${ACCUMULO_HOME}/conf
+XML_FILES=${ACCUMULO_CONF_DIR}
 CLASSPATH=${XML_FILES}:${START_JAR}:${COMMONS_JCI_JARS}
 
-if [ -z $JAVA_HOME -o ! -d $JAVA_HOME ]; then
-    echo "JAVA_HOME is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
-    exit 1
-fi
-if [ -z $HADOOP_HOME -o ! -d $HADOOP_HOME ]; then
-    echo "HADOOP_HOME is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
-    exit 1
-fi
-if [ -z $ZOOKEEPER_HOME -o ! -d $ZOOKEEPER_HOME ]; then
-    echo "ZOOKEEPER_HOME is not set.  Please make sure it's set globally or in conf/accumulo-env.sh"
-    exit 1
-fi
-
-#Export the variables just in case they are not exported
-#This makes them available to java
-export JAVA_HOME=$JAVA_HOME
-export HADOOP_HOME=$HADOOP_HOME
-export ZOOKEEPER_HOME=$ZOOKEEPER_HOME
-
 JAVA=$JAVA_HOME/bin/java
 PLATFORM="`$JAVA -cp $CLASSPATH org.apache.accumulo.start.Platform`"
 

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/config.sh
----------------------------------------------------------------------
diff --git a/bin/config.sh b/bin/config.sh
index 6a88e61..a89115a 100755
--- a/bin/config.sh
+++ b/bin/config.sh
@@ -15,6 +15,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# Guarantees that Accumulo and its environment variables are set.
+#
+# Values set by script that can be user provided.  If not provided script attempts to infer.
+#  ACCUMULO_CONF_DIR  Location where accumulo-env.sh, accumulo-site.xml and friends will be read from
+#  ACCUMULO_HOME      Home directory for Accumulo
+#  ACCUMULO_LOG_DIR   Directory for Accumulo daemon logs
+#  ACCUMULO_VERSION   Accumulo version name
+#  HADOOP_HOME        Home dir for hadoop.
+# 
+# Values always set by script.
+#  GC                 Machine to rn GC daemon on.  Used by start-here.sh script
+#  MONITOR            Machine to run monitor daemon on. Used by start-here.sh script
+#  SSH                Default ssh parameters used to start daemons
+
 this="$0"
 while [ -h "$this" ]; do
     ls=`ls -ld "$this"`
@@ -33,8 +47,17 @@ this="$bin/$script"
 ACCUMULO_HOME=`dirname "$this"`/..
 export ACCUMULO_HOME=`cd $ACCUMULO_HOME; pwd`
 
-if [ -f $ACCUMULO_HOME/conf/accumulo-env.sh ] ; then
-. $ACCUMULO_HOME/conf/accumulo-env.sh
+ACCUMULO_CONF_DIR="${ACCUMULO_CONF_DIR:-$ACCUMULO_HOME/conf}"
+export ACCUMULO_CONF_DIR
+if [ -z "$ACCUMULO_CONF_DIR" -o ! -d "$ACCUMULO_CONF_DIR" ]
+then
+  echo "ACCUMULO_CONF_DIR=$ACCUMULO_CONF_DIR is not a valid directory.  Please make sure it exists"
+  exit 1
+fi
+
+
+if [ -f $ACCUMULO_CONF_DIR/accumulo-env.sh ] ; then
+. $ACCUMULO_CONF_DIR/accumulo-env.sh
 fi
 
 if [ -z ${ACCUMULO_LOG_DIR} ]; then
@@ -67,17 +90,17 @@ then
 fi
 export HADOOP_HOME
 
-if [ ! -f "$ACCUMULO_HOME/conf/masters" -o ! -f "$ACCUMULO_HOME/conf/slaves" ]
+if [ ! -f "$ACCUMULO_CONF_DIR/masters" -o ! -f "$ACCUMULO_CONF_DIR/slaves" ]
 then
-    if [ ! -f "$ACCUMULO_HOME/conf/masters" -a ! -f "$ACCUMULO_HOME/conf/slaves" ]
+    if [ ! -f "$ACCUMULO_CONF_DIR/masters" -a ! -f "$ACCUMULO_CONF_DIR/slaves" ]
     then
         echo "STANDALONE: Missing both conf/masters and conf/slaves files"
         echo "STANDALONE: Assuming single-node (localhost only) instance"
-        echo "STANDALONE: echo "`hostname`" > $ACCUMULO_HOME/conf/masters"
-        echo `hostname` > "$ACCUMULO_HOME/conf/masters"
-        echo "STANDALONE: echo "`hostname`" > $ACCUMULO_HOME/conf/slaves"
-        echo `hostname` > "$ACCUMULO_HOME/conf/slaves"
-        fgrep -s logger.dir.walog "$ACCUMULO_HOME/conf/accumulo-site.xml" > /dev/null
+        echo "STANDALONE: echo "`hostname`" > $ACCUMULO_CONF_DIR/masters"
+        echo `hostname` > "$ACCUMULO_CONF_DIR/masters"
+        echo "STANDALONE: echo "`hostname`" > $ACCUMULO_CONF_DIR/slaves"
+        echo `hostname` > "$ACCUMULO_CONF_DIR/slaves"
+        fgrep -s logger.dir.walog "$ACCUMULO_CONF_DIR/accumulo-site.xml" > /dev/null
         WALOG_CONFIGURED=$?
         if [ $WALOG_CONFIGURED -ne 0 -a ! -e "$ACCUMULO_HOME/walogs" ]
         then
@@ -85,28 +108,28 @@ then
           mkdir "$ACCUMULO_HOME/walogs"
           echo "STANDALONE: mkdir \"$ACCUMULO_HOME/walogs\""
         fi
-        if [ ! -e "$ACCUMULO_HOME/conf/accumulo-metrics.xml" ]
+        if [ ! -e "$ACCUMULO_CONF_DIR/accumulo-metrics.xml" ]
         then
           echo "STANDALONE: Creating default metrics configuration"
-          cp "$ACCUMULO_HOME/conf/accumulo-metrics.xml.example" "$ACCUMULO_HOME/conf/accumulo-metrics.xml"
+          cp "$ACCUMULO_CONF_DIR/accumulo-metrics.xml.example" "$ACCUMULO_CONF_DIR/accumulo-metrics.xml"
         fi
     else
-        echo "You are missing either $ACCUMULO_HOME/conf/masters or $ACCUMULO_HOME/conf/slaves"
+        echo "You are missing either $ACCUMULO_CONF_DIR/masters or $ACCUMULO_CONF_DIR/slaves"
         echo "Please configure them both for a multi-node instance, or delete them both for a single-node (localhost only) instance"
         exit 1
     fi
 fi
-MASTER1=`grep -v '^#' "$ACCUMULO_HOME/conf/masters" | head -1`
+MASTER1=`grep -v '^#' "$ACCUMULO_CONF_DIR/masters" | head -1`
 GC=$MASTER1
 MONITOR=$MASTER1
-if [ -f "$ACCUMULO_HOME/conf/gc" ]; then
-    GC=`grep -v '^#' "$ACCUMULO_HOME/conf/gc" | head -1`
+if [ -f "$ACCUMULO_CONF_DIR/gc" ]; then
+    GC=`grep -v '^#' "$ACCUMULO_CONF_DIR/gc" | head -1`
 fi
-if [ -f "$ACCUMULO_HOME/conf/monitor" ]; then
-    MONITOR=`grep -v '^#' "$ACCUMULO_HOME/conf/monitor" | head -1`
+if [ -f "$ACCUMULO_CONF_DIR/monitor" ]; then
+    MONITOR=`grep -v '^#' "$ACCUMULO_CONF_DIR/monitor" | head -1`
 fi
-if [ ! -f "$ACCUMULO_HOME/conf/tracers" ]; then
-    echo "$MASTER1" > "$ACCUMULO_HOME/conf/tracers"
+if [ ! -f "$ACCUMULO_CONF_DIR/tracers" ]; then
+    echo "$MASTER1" > "$ACCUMULO_CONF_DIR/tracers"
 fi
 SSH='ssh -qnf -o ConnectTimeout=2'
 

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/start-all.sh
----------------------------------------------------------------------
diff --git a/bin/start-all.sh b/bin/start-all.sh
index 28cf6fc..5bee329 100755
--- a/bin/start-all.sh
+++ b/bin/start-all.sh
@@ -22,8 +22,8 @@ bin=`cd "$bin"; pwd`
 . "$bin"/config.sh
 unset DISPLAY
 
-if [ ! -f $ACCUMULO_HOME/conf/accumulo-env.sh ] ; then
-  echo "${ACCUMULO_HOME}/conf/accumulo-env.sh does not exist. Please make sure you configure Accumulo before you run anything"
+if [ ! -f $ACCUMULO_CONF_DIR/accumulo-env.sh ] ; then
+  echo "${ACCUMULO_CONF_DIR}/accumulo-env.sh does not exist. Please make sure you configure Accumulo before you run anything"
   echo "We provide examples you can copy in ${ACCUMULO_HOME}/conf/examples/ which are set up for your memory footprint"
   exit 1
 fi
@@ -47,7 +47,7 @@ if [ "$1" != "--notSlaves" ] ; then
 fi
 
 ${bin}/accumulo org.apache.accumulo.server.master.state.SetGoalState NORMAL
-for master in `grep -v '^#' "$ACCUMULO_HOME/conf/masters"`
+for master in `grep -v '^#' "$ACCUMULO_CONF_DIR/masters"`
 do
     ${bin}/start-server.sh $master master
 done
@@ -56,7 +56,7 @@ ${bin}/start-server.sh $GC gc "garbage collector"
 
 ${bin}/start-server.sh $MONITOR monitor 
 
-for tracer in `grep -v '^#' "$ACCUMULO_HOME/conf/tracers"`
+for tracer in `grep -v '^#' "$ACCUMULO_CONF_DIR/tracers"`
 do
    ${bin}/start-server.sh $tracer tracer
 done

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/start-here.sh
----------------------------------------------------------------------
diff --git a/bin/start-here.sh b/bin/start-here.sh
index b3d494e..22c8a04 100755
--- a/bin/start-here.sh
+++ b/bin/start-here.sh
@@ -27,7 +27,7 @@ bin=`cd "$bin"; pwd`
 HOSTS="`hostname -a` `hostname` localhost"
 for host in $HOSTS
 do
-    if grep -q "^${host}\$" $ACCUMULO_HOME/conf/slaves
+    if grep -q "^${host}\$" $ACCUMULO_CONF_DIR/slaves
     then
        ${bin}/start-server.sh $host logger
        ${bin}/start-server.sh $host tserver "tablet server"
@@ -37,7 +37,7 @@ done
 
 for host in $HOSTS
 do
-    if grep -q "^${host}\$" $ACCUMULO_HOME/conf/masters
+    if grep -q "^${host}\$" $ACCUMULO_CONF_DIR/masters
     then
        ${bin}/accumulo org.apache.accumulo.server.master.state.SetGoalState NORMAL
        ${bin}/start-server.sh $host master
@@ -65,7 +65,7 @@ done
 
 for host in $HOSTS
 do
-    if grep -q "^${host}\$" $ACCUMULO_HOME/conf/tracers
+    if grep -q "^${host}\$" $ACCUMULO_CONF_DIR/tracers
     then
 	${bin}/start-server.sh $host tracer 
 	break

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/start-server.sh
----------------------------------------------------------------------
diff --git a/bin/start-server.sh b/bin/start-server.sh
index 59cf1a3..7655319 100755
--- a/bin/start-server.sh
+++ b/bin/start-server.sh
@@ -35,7 +35,7 @@ if [ -z "$LONGNAME" ]
 then
    LONGNAME="$2"
 fi
-SLAVES=`wc -l < ${ACCUMULO_HOME}/conf/slaves`
+SLAVES=`wc -l < ${ACCUMULO_CONF_DIR}/slaves`
 
 IFCONFIG=/sbin/ifconfig
 if [ ! -x $IFCONFIG ]

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/stop-all.sh
----------------------------------------------------------------------
diff --git a/bin/stop-all.sh b/bin/stop-all.sh
index f318397..a717e42 100755
--- a/bin/stop-all.sh
+++ b/bin/stop-all.sh
@@ -37,7 +37,7 @@ sleep 5
 #look for master and gc processes not killed by 'admin stopAll'
 for signal in TERM KILL
 do
-   for master in `grep -v '^#' "$ACCUMULO_HOME/conf/masters"`
+   for master in `grep -v '^#' "$ACCUMULO_CONF_DIR/masters"`
    do
       ${bin}/stop-server.sh $master "$ACCUMULO_HOME/.*/accumulo-start.*.jar" master $signal
    done
@@ -46,7 +46,7 @@ do
 
    ${bin}/stop-server.sh $MONITOR "$ACCUMULO_HOME/.*/accumulo-start.*.jar" monitor $signal
 
-   for tracer in `grep -v '^#' "$ACCUMULO_HOME/conf/tracers"`
+   for tracer in `grep -v '^#' "$ACCUMULO_CONF_DIR/tracers"`
    do
       ${bin}/stop-server.sh $tracer "$ACCUMULO_HOME/.*/accumulo-start.*.jar" tracer $signal
    done

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/stop-here.sh
----------------------------------------------------------------------
diff --git a/bin/stop-here.sh b/bin/stop-here.sh
index 9532e22..f7fbad0 100755
--- a/bin/stop-here.sh
+++ b/bin/stop-here.sh
@@ -26,13 +26,13 @@ bin=`cd "$bin"; pwd`
 
 ACCUMULO="$ACCUMULO_HOME/.*/accumulo-start.*.jar"
 
-if grep -q localhost $ACCUMULO_HOME/conf/slaves
+if grep -q localhost $ACCUMULO_CONF_DIR/slaves
 then
     $bin/accumulo admin stop localhost
 else
     for host in `hostname -a`
     do
-       if grep -q $host $ACCUMULO_HOME/conf/slaves
+       if grep -q $host $ACCUMULO_CONF_DIR/slaves
        then
           $bin/accumulo admin stop $host
        fi

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/tdown.sh
----------------------------------------------------------------------
diff --git a/bin/tdown.sh b/bin/tdown.sh
index 1283799..12148f5 100755
--- a/bin/tdown.sh
+++ b/bin/tdown.sh
@@ -23,7 +23,7 @@ bin=`cd "$bin"; pwd`
 
 HADOOP_CMD=$HADOOP_LOCATION/bin/hadoop
 
-SLAVES=$ACCUMULO_HOME/conf/slaves
+SLAVES=$ACCUMULO_CONF_DIR/slaves
 
 echo 'stopping unresponsive tablet servers (if any) ...'
 for server in `cat $SLAVES | grep -v '^#' `; do

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/bin/tup.sh
----------------------------------------------------------------------
diff --git a/bin/tup.sh b/bin/tup.sh
index 53fd9a4..bf52feb 100755
--- a/bin/tup.sh
+++ b/bin/tup.sh
@@ -21,7 +21,7 @@ bin=`cd "$bin"; pwd`
 
 . "$bin"/config.sh
 
-SLAVES=$ACCUMULO_HOME/conf/slaves
+SLAVES=$ACCUMULO_CONF_DIR/slaves
 
 echo -n "Starting tablet servers and loggers ..."
 

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/1GB/native-standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/1GB/native-standalone/accumulo-env.sh b/conf/examples/1GB/native-standalone/accumulo-env.sh
index 37eb2fc..5410cf9 100755
--- a/conf/examples/1GB/native-standalone/accumulo-env.sh
+++ b/conf/examples/1GB/native-standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx128m -Xms128m "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx128m -Xms128m"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx64m -Xms64m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx384m -Xms256m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx128m -Xms64m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/1GB/standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/1GB/standalone/accumulo-env.sh b/conf/examples/1GB/standalone/accumulo-env.sh
index f38e5b1..6214cf7 100755
--- a/conf/examples/1GB/standalone/accumulo-env.sh
+++ b/conf/examples/1GB/standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx384m -Xms384m "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx128m -Xms128m"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx64m -Xms64m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx384m -Xms256m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx128m -Xms64m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/2GB/native-standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/2GB/native-standalone/accumulo-env.sh b/conf/examples/2GB/native-standalone/accumulo-env.sh
index 1fd641f..77cc243 100755
--- a/conf/examples/2GB/native-standalone/accumulo-env.sh
+++ b/conf/examples/2GB/native-standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx256m -Xms256m "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx256m -Xms256m"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx128m -Xms128m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx768m -Xms256m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx256m -Xms64m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/2GB/standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/2GB/standalone/accumulo-env.sh b/conf/examples/2GB/standalone/accumulo-env.sh
index 290d81e..dee9937 100755
--- a/conf/examples/2GB/standalone/accumulo-env.sh
+++ b/conf/examples/2GB/standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx768m -Xms768m "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx256m -Xms256m"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx128m -Xms128m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx768m -Xms256m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx256m -Xms64m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/3GB/native-standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/3GB/native-standalone/accumulo-env.sh b/conf/examples/3GB/native-standalone/accumulo-env.sh
index c537161..3014554 100755
--- a/conf/examples/3GB/native-standalone/accumulo-env.sh
+++ b/conf/examples/3GB/native-standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx1g -Xms1g -XX:NewSize=500m -XX:MaxNewSize=500m "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx1g -Xms1g"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx256m -Xms256m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx1g -Xms256m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx1g -Xms256m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/3GB/standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/3GB/standalone/accumulo-env.sh b/conf/examples/3GB/standalone/accumulo-env.sh
index eaeed4e..23080d3 100755
--- a/conf/examples/3GB/standalone/accumulo-env.sh
+++ b/conf/examples/3GB/standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx2g -Xms2g -XX:NewSize=1G -XX:MaxNewSize=1G "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx1g -Xms1g"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx256m -Xms256m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx1g -Xms256m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx1g -Xms256m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/512MB/native-standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/512MB/native-standalone/accumulo-env.sh b/conf/examples/512MB/native-standalone/accumulo-env.sh
index 0a59dda..49ec64d 100755
--- a/conf/examples/512MB/native-standalone/accumulo-env.sh
+++ b/conf/examples/512MB/native-standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx48m -Xms48m "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx128m -Xms128m"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx64m -Xms64m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx128m -Xms128m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx128m -Xms64m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/conf/examples/512MB/standalone/accumulo-env.sh
----------------------------------------------------------------------
diff --git a/conf/examples/512MB/standalone/accumulo-env.sh b/conf/examples/512MB/standalone/accumulo-env.sh
index e01f088..e0ae73e 100755
--- a/conf/examples/512MB/standalone/accumulo-env.sh
+++ b/conf/examples/512MB/standalone/accumulo-env.sh
@@ -32,9 +32,9 @@ test -z "$JAVA_HOME"             && export JAVA_HOME=/path/to/java
 test -z "$HADOOP_HOME"           && export HADOOP_HOME=/path/to/hadoop
 test -z "$ZOOKEEPER_HOME"        && export ZOOKEEPER_HOME=/path/to/zookeeper
 test -z "$ACCUMULO_LOG_DIR"      && export ACCUMULO_LOG_DIR=$ACCUMULO_HOME/logs
-if [ -f ${ACCUMULO_HOME}/conf/accumulo.policy ]
+if [ -f ${ACCUMULO_CONF_DIR}/accumulo.policy ]
 then
-   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_HOME}/conf/accumulo.policy"
+   POLICY="-Djava.security.manager -Djava.security.policy=${ACCUMULO_CONF_DIR}/accumulo.policy"
 fi
 test -z "$ACCUMULO_TSERVER_OPTS" && export ACCUMULO_TSERVER_OPTS="${POLICY} -Xmx128m -Xms128m "
 test -z "$ACCUMULO_MASTER_OPTS"  && export ACCUMULO_MASTER_OPTS="${POLICY} -Xmx128m -Xms128m"
@@ -43,4 +43,4 @@ test -z "$ACCUMULO_GC_OPTS"      && export ACCUMULO_GC_OPTS="-Xmx64m -Xms64m"
 test -z "$ACCUMULO_LOGGER_OPTS"  && export ACCUMULO_LOGGER_OPTS="-Xmx128m -Xms128m"
 test -z "$ACCUMULO_GENERAL_OPTS" && export ACCUMULO_GENERAL_OPTS="-XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=75"
 test -z "$ACCUMULO_OTHER_OPTS"   && export ACCUMULO_OTHER_OPTS="-Xmx128m -Xms64m"
-export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_HOME/conf/masters ; echo localhost ) 2>/dev/null | head -1`
+export ACCUMULO_LOG_HOST=`(grep -v '^#' $ACCUMULO_CONF_DIR/masters ; echo localhost ) 2>/dev/null | head -1`

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/docs/config.html
----------------------------------------------------------------------
diff --git a/docs/config.html b/docs/config.html
index 70f4855..97c2c6b 100644
--- a/docs/config.html
+++ b/docs/config.html
@@ -136,7 +136,7 @@
     <td>general.classpaths</td>
     <td><b><a href='#STRING'>string</a></b></td>
     <td>no</td>
-    <td><pre>$ACCUMULO_HOME/conf,
+    <td><pre>$ACCUMULO_CONF_DIR,
 $ACCUMULO_HOME/lib/[^.].$ACCUMULO_VERSION.jar,
 $ACCUMULO_HOME/lib/[^.].*.jar,
 $ZOOKEEPER_HOME/zookeeper[^.].*.jar,

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/src/server/src/main/java/org/apache/accumulo/server/Accumulo.java
----------------------------------------------------------------------
diff --git a/src/server/src/main/java/org/apache/accumulo/server/Accumulo.java b/src/server/src/main/java/org/apache/accumulo/server/Accumulo.java
index 60f4788..b2feb5c 100644
--- a/src/server/src/main/java/org/apache/accumulo/server/Accumulo.java
+++ b/src/server/src/main/java/org/apache/accumulo/server/Accumulo.java
@@ -117,10 +117,10 @@ public class Accumulo {
       System.setProperty("org.apache.accumulo.core.host.log", localhost);
     
     // Use a specific log config, if it exists
-    String logConfig = String.format("%s/conf/%s_logger.xml", System.getenv("ACCUMULO_HOME"), application);
+    String logConfig = String.format("%s/%s_logger.xml", System.getenv("ACCUMULO_CONF_DIR"), application);
     if (!new File(logConfig).exists()) {
       // otherwise, use the generic config
-      logConfig = String.format("%s/conf/generic_logger.xml", System.getenv("ACCUMULO_HOME"));
+      logConfig = String.format("%s/generic_logger.xml", System.getenv("ACCUMULO_CONF_DIR"));
     }
     // Turn off messages about not being able to reach the remote logger... we protect against that.
     LogLog.setQuietMode(true);

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/src/start/src/main/java/org/apache/accumulo/start/classloader/AccumuloClassLoader.java
----------------------------------------------------------------------
diff --git a/src/start/src/test/java/org/apache/accumulo/start/Test.java b/src/start/src/test/java/org/apache/accumulo/start/Test.java
index 376d563..7da905c 100644
--- a/src/start/src/test/java/org/apache/accumulo/start/Test.java
+++ b/src/start/src/test/java/org/apache/accumulo/start/Test.java
@@ -181,6 +181,7 @@ public class Test extends TestCase {
   
   public void testChangingDirectory() throws Exception {
     String configFile = System.getProperty("org.apache.accumulo.config.file", "accumulo-site.xml");
+    // This does not use ACCUMULO_CONF_DIR since it is used to get to the conf/examples dirs
     String CONF_DIR = System.getenv("ACCUMULO_HOME") + "/conf/";
     String SITE_CONF = CONF_DIR + configFile;
     File oldConf = new File(SITE_CONF);

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/auto/TestUtils.py
----------------------------------------------------------------------
diff --git a/test/system/auto/TestUtils.py b/test/system/auto/TestUtils.py
index 42c137b..4b5efdf 100755
--- a/test/system/auto/TestUtils.py
+++ b/test/system/auto/TestUtils.py
@@ -48,7 +48,7 @@ WALOG = os.path.join(ACCUMULO_HOME, 'walogs', ID)
 LOG_PROPERTIES= os.path.join(ACCUMULO_HOME, 'conf', 'log4j.properties')
 LOG_GENERIC = os.path.join(ACCUMULO_HOME, 'conf', 'generic_logger.xml')
 LOG_MONITOR = os.path.join(ACCUMULO_HOME, 'conf', 'monitor_logger.xml')
-General_CLASSPATH = ("$ACCUMULO_HOME/lib/[^.].$ACCUMULO_VERSION.jar, $ACCUMULO_HOME/lib/[^.].*.jar, $ZOOKEEPER_HOME/zookeeper[^.].*.jar,"
+General_CLASSPATH = ("$ACCUMULO_CONF_DIR,$ACCUMULO_HOME/lib/[^.].$ACCUMULO_VERSION.jar, $ACCUMULO_HOME/lib/[^.].*.jar, $ZOOKEEPER_HOME/zookeeper[^.].*.jar,"
 "$HADOOP_HOME/conf,$HADOOP_HOME/[^.].*.jar, $HADOOP_HOME/lib/[^.].*.jar") 
 
 log = logging.getLogger('test.auto')

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/continuous/agitator.pl
----------------------------------------------------------------------
diff --git a/test/system/continuous/agitator.pl b/test/system/continuous/agitator.pl
index be3a0c6..c074665 100755
--- a/test/system/continuous/agitator.pl
+++ b/test/system/continuous/agitator.pl
@@ -40,7 +40,7 @@ if($minKill > $maxKill){
 	die("minKill > maxKill $minKill > $maxKill");
 }
 
-@slavesRaw = `cat $ACCUMULO_HOME/conf/slaves`;
+@slavesRaw = `cat $ACCUMULO_CONF_DIR/slaves`;
 chomp(@slavesRaw);
 
 for $slave (@slavesRaw){

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/continuous/magitator.pl
----------------------------------------------------------------------
diff --git a/test/system/continuous/magitator.pl b/test/system/continuous/magitator.pl
index 8b22505..a0cab60 100755
--- a/test/system/continuous/magitator.pl
+++ b/test/system/continuous/magitator.pl
@@ -29,7 +29,7 @@ $ACCUMULO_HOME="../../..";
 $sleep1 = $ARGV[0];
 $sleep2 = $ARGV[1];
 
-@mastersRaw = `cat $ACCUMULO_HOME/conf/masters`;
+@mastersRaw = `cat $ACCUMULO_CONF_DIR/masters`;
 chomp(@mastersRaw);
 
 for $master (@mastersRaw){
@@ -52,10 +52,10 @@ while(1){
 		system($cmd);
 	}else{
 		print STDERR "$t Killing all masters\n";
-		$cmd = "pssh -h $ACCUMULO_HOME/conf/masters \"pkill -f '[ ]org.apache.accumulo.start.*master'\" < /dev/null";
+		$cmd = "pssh -h $ACCUMULO_CONF_DIR/masters \"pkill -f '[ ]org.apache.accumulo.start.*master'\" < /dev/null";
 		print "$t $cmd\n";
 		system($cmd);
-		$cmd = "pssh -h $ACCUMULO_HOME/conf/masters \"pkill -f '[ ]org.apache.accumulo.start.*gc'\" < /dev/null";
+		$cmd = "pssh -h $ACCUMULO_CONF_DIR/masters \"pkill -f '[ ]org.apache.accumulo.start.*gc'\" < /dev/null";
 		print "$t $cmd\n";
 		system($cmd);
 	}

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/continuous/mapred-setup.sh
----------------------------------------------------------------------
diff --git a/test/system/continuous/mapred-setup.sh b/test/system/continuous/mapred-setup.sh
index b714137..3e5b227 100755
--- a/test/system/continuous/mapred-setup.sh
+++ b/test/system/continuous/mapred-setup.sh
@@ -19,7 +19,7 @@
 # for running a map reduce job
 
 . continuous-env.sh
-. $ACCUMULO_HOME/conf/accumulo-env.sh
+. $ACCUMULO_CONF_DIR/accumulo-env.sh
 
 SERVER_CMD='ls -1 $ACCUMULO_HOME/lib/accumulo-server-*[!javadoc\|sources].jar'
 

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/continuous/start-stats.sh
----------------------------------------------------------------------
diff --git a/test/system/continuous/start-stats.sh b/test/system/continuous/start-stats.sh
index ae757bc..04b16a2 100755
--- a/test/system/continuous/start-stats.sh
+++ b/test/system/continuous/start-stats.sh
@@ -22,7 +22,7 @@ mkdir -p $CONTINUOUS_LOG_DIR
 
 CONFIG_OUT=$CONTINUOUS_LOG_DIR/`date +%Y%m%d%H%M%S`_`hostname`_config.out
 
-cat $ACCUMULO_HOME/conf/accumulo-env.sh > $CONFIG_OUT
+cat $ACCUMULO_CONF_DIR/accumulo-env.sh > $CONFIG_OUT
 echo >> $CONFIG_OUT
 echo -e "config -np\nconfig -t $TABLE -np\nquit" | $ACCUMULO_HOME/bin/accumulo shell -u $USER -p $PASS >> $CONFIG_OUT
 echo >> $CONFIG_OUT

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/randomwalk/README
----------------------------------------------------------------------
diff --git a/test/system/randomwalk/README b/test/system/randomwalk/README
index 0c33310..78a50c6 100644
--- a/test/system/randomwalk/README
+++ b/test/system/randomwalk/README
@@ -4,7 +4,7 @@ The randomwalk framework needs to be configured for your Accumulo instance by
 doing the following steps:
 
 1.  Make sure you have both ACCUMULO_HOME and HADOOP_HOME set in your 
-    $ACCUMULO_HOME/conf/accumulo-env.sh.
+    $ACCUMULO_CONF_DIR/accumulo-env.sh.
 
 2.  Create 'randomwalk.conf' file in the conf directory containing settings
     needed by walkers to connect to Accumulo.

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/randomwalk/bin/reset-cluster.sh
----------------------------------------------------------------------
diff --git a/test/system/randomwalk/bin/reset-cluster.sh b/test/system/randomwalk/bin/reset-cluster.sh
index 3ffea0c..83dfcee 100755
--- a/test/system/randomwalk/bin/reset-cluster.sh
+++ b/test/system/randomwalk/bin/reset-cluster.sh
@@ -34,8 +34,8 @@ this="$bin/$script"
 ACCUMULO_HOME=`dirname "$this"`/../../../..
 export ACCUMULO_HOME=`cd $ACCUMULO_HOME; pwd`
 
-if [ -f $ACCUMULO_HOME/conf/accumulo-env.sh ] ; then
-. $ACCUMULO_HOME/conf/accumulo-env.sh
+if [ -f $ACCUMULO_CONF_DIR/accumulo-env.sh ] ; then
+. $ACCUMULO_CONF_DIR/accumulo-env.sh
 fi
 
 if [ -z $HADOOP_HOME ] ; then
@@ -49,7 +49,7 @@ if [ "$1" = "" ] ; then
 fi
 
 echo 'killing accumulo'
-pssh -h $ACCUMULO_HOME/conf/slaves "pkill -f org.apache.accumulo.start" < /dev/null
+pssh -h $ACCUMULO_CONF_DIR/slaves "pkill -f org.apache.accumulo.start" < /dev/null
 pkill -f org.apache.accumulo.start
 pkill -f agitator.pl
 
@@ -64,10 +64,10 @@ rm -f $ACCUMULO_HOME/test/system/continuous/logs/*
 rm -f ~/rwlogs/*
 
 echo 'removing old code'
-pssh -h $ACCUMULO_HOME/conf/slaves "rm -rf $ACCUMULO_HOME" < /dev/null
+pssh -h $ACCUMULO_CONF_DIR/slaves "rm -rf $ACCUMULO_HOME" < /dev/null
 
 echo 'pushing new code'
-prsync -r -h $ACCUMULO_HOME/conf/slaves $ACCUMULO_HOME /opt/dev
+prsync -r -h $ACCUMULO_CONF_DIR/slaves $ACCUMULO_HOME /opt/dev
 
 echo 'removing /accumulo dir'
 $HADOOP_HOME/bin/hadoop fs -rmr /accumulo

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/randomwalk/bin/start-all.sh
----------------------------------------------------------------------
diff --git a/test/system/randomwalk/bin/start-all.sh b/test/system/randomwalk/bin/start-all.sh
index 660c87e..67296de 100755
--- a/test/system/randomwalk/bin/start-all.sh
+++ b/test/system/randomwalk/bin/start-all.sh
@@ -34,8 +34,8 @@ this="$bin/$script"
 ACCUMULO_HOME=`dirname "$this"`/../../../..
 export ACCUMULO_HOME=`cd $ACCUMULO_HOME; pwd`
 
-if [ -f $ACCUMULO_HOME/conf/accumulo-env.sh ] ; then
-. $ACCUMULO_HOME/conf/accumulo-env.sh
+if [ -f $ACCUMULO_CONF_DIR/accumulo-env.sh ] ; then
+. $ACCUMULO_CONF_DIR/accumulo-env.sh
 fi
 
 

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/randomwalk/bin/start-local.sh
----------------------------------------------------------------------
diff --git a/test/system/randomwalk/bin/start-local.sh b/test/system/randomwalk/bin/start-local.sh
index a27523e..c02b942 100755
--- a/test/system/randomwalk/bin/start-local.sh
+++ b/test/system/randomwalk/bin/start-local.sh
@@ -35,8 +35,8 @@ this="$bin/$script"
 ACCUMULO_HOME=`dirname "$this"`/../../../..
 export ACCUMULO_HOME=`cd $ACCUMULO_HOME; pwd`
 
-if [ -f $ACCUMULO_HOME/conf/accumulo-env.sh ] ; then
-. $ACCUMULO_HOME/conf/accumulo-env.sh
+if [ -f $ACCUMULO_CONF_DIR/accumulo-env.sh ] ; then
+. $ACCUMULO_CONF_DIR/accumulo-env.sh
 fi
 
 if [ -z "$HADOOP_HOME" ] ; then

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/test/system/scalability/run.py
----------------------------------------------------------------------
diff --git a/test/system/scalability/run.py b/test/system/scalability/run.py
index e74fbf9..d0f9f51 100755
--- a/test/system/scalability/run.py
+++ b/test/system/scalability/run.py
@@ -57,7 +57,7 @@ def runTest(testName, siteConfig, testDir, numNodes, fdata):
     syscall('head -n %d %s > %s' % (numNodes,slavesPath,nodesPath))
 
     log('Copying slaves file to accumulo config')
-    syscall('cp '+nodesPath+' $ACCUMULO_HOME/conf/slaves');
+    syscall('cp '+nodesPath+' $ACCUMULO_CONF_DIR/slaves');
 
     log('Removing /accumulo directory in HDFS')
     syscall("hadoop fs -rmr /accumulo")
diff --git a/src/start/src/main/java/org/apache/accumulo/start/classloader/AccumuloClassLoader.java b/src/start/src/main/java/org/apache/accumulo/start/classloader/AccumuloClassLoader.java
index 0e5597f..8d217d7 100644
--- a/src/start/src/main/java/org/apache/accumulo/start/classloader/AccumuloClassLoader.java
+++ b/src/start/src/main/java/org/apache/accumulo/start/classloader/AccumuloClassLoader.java
@@ -106,7 +106,9 @@ public class AccumuloClassLoader {
   
   public static final String DYNAMIC_CLASSPATH_PROPERTY_NAME = "general.dynamic.classpaths";
   
-  public static final String ACCUMULO_CLASSPATH_VALUE = "$ACCUMULO_HOME/conf,\n" + "$ACCUMULO_HOME/lib/[^.].$ACCUMULO_VERSION.jar,\n"
+  public static final String ACCUMULO_CLASSPATH_VALUE = 
+      "$ACCUMULO_CONF_DIR,\n" 
+      + "$ACCUMULO_HOME/lib/[^.].$ACCUMULO_VERSION.jar,\n"
       + "$ACCUMULO_HOME/lib/[^.].*.jar,\n" + "$ZOOKEEPER_HOME/zookeeper[^.].*.jar,\n" + "$HADOOP_HOME/[^.].*.jar,\n" + "$HADOOP_HOME/conf,\n"
       + "$HADOOP_HOME/lib/[^.].*.jar,\n";
   
@@ -120,8 +122,11 @@ public class AccumuloClassLoader {
   private static final String SITE_CONF;
   static {
     String configFile = System.getProperty("org.apache.accumulo.config.file", "accumulo-site.xml");
-    if (System.getenv("ACCUMULO_HOME") != null) {
-      // accumulo home should be set
+    if (System.getenv("ACCUMULO_CONF_DIR") != null) {
+      // accumulo conf dir should be set.
+      SITE_CONF = System.getenv("ACCUMULO_CONF_DIR") + "/" + configFile;
+    } else if (System.getenv("ACCUMULO_HOME") != null) {
+      // if no accumulo conf dir, try accumulo home default
       SITE_CONF = System.getenv("ACCUMULO_HOME") + "/conf/" + configFile;
     } else {
       /*

http://git-wip-us.apache.org/repos/asf/accumulo/blob/cd8ebfe8/src/start/src/test/java/org/apache/accumulo/start/Test.java
----------------------------------------------------------------------